@@ -9,9 +9,9 @@ use Cwd ();
 use Exporter 'import';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-11-23'; # DATE
+our $DATE = '2023-11-24'; # DATE
 our $DIST = 'File-Util-Test'; # DIST
-our $VERSION = '0.630'; # VERSION
+our $VERSION = '0.631'; # VERSION
 
 our @EXPORT_OK = qw(
                        file_exists
@@ -44,6 +44,7 @@ our @EXPORT_OK = qw(
                        get_dir_non_dot_files
                        get_dir_only_file
                        get_dir_only_subdir
+                       get_dir_only_symlink
                );
 
 our %SPEC;
@@ -429,6 +430,26 @@ sub get_dir_only_subdir {
     $res;
 }
 
+sub get_dir_only_symlink {
+    my $opts = ref $_[0] eq 'HASH' ? {%{shift()}} : {};
+    die "Unknown option(s): ".join(", ", keys %$opts) if keys %$opts;
+
+    my ($dir) = @_;
+    $dir //= ".";
+
+    opendir my($dh), $dir or die "Can't opendir $dir: $!";
+    my $res;
+    while (defined(my $e = readdir $dh)) {
+        next if $e eq '.' || $e eq '..';
+        my @st = lstat "$dir/$e";
+        return unless -l _;
+        return if defined $res;
+        $res = $e;
+    }
+    return unless defined $res;
+    $res;
+}
+
 1;
 # ABSTRACT: Utilities related mostly to testing/checking for files in directories
 
@@ -444,7 +465,7 @@ File::Util::Test - Utilities related mostly to testing/checking for files in dir
 
 =head1 VERSION
 
-This document describes version 0.630 of File::Util::Test (from Perl distribution File-Util-Test), released on 2023-11-23.
+This document describes version 0.631 of File::Util::Test (from Perl distribution File-Util-Test), released on 2023-11-24.
 
 =head1 SYNOPSIS
 
@@ -477,6 +498,7 @@ This document describes version 0.630 of File::Util::Test (from Perl distributio
      get_dir_non_dot_files
      get_dir_only_file
      get_dir_only_subdir
+     get_dir_only_symlink
  );
 
  print "file exists" if file_exists("/path/to/file/or/dir");
@@ -863,6 +885,15 @@ Boolean. If set to true, then ignore files.
 
 =back
 
+=head2 get_dir_only_symlink
+
+Usage:
+
+ my $filename = get_dir_only_symlink([ \%opts, ] [ $dir ]);
+
+Return symlink name inside directory C<$dir> (or current directory if
+unspecified) only if C<$dir> has a single symlink and nothing else.
+
 =head1 FAQ
 
 =head2 Where is file_empty()?
